import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '../views/layout/Layout'
import common from '../views/layout/common'

/**
* hidden: true                   if `hidden:true` will not show in the sidebar(default is false)
* alwaysShow: true               if set true, will always show the root menu, whatever its child routes length
*                                if not set alwaysShow, only more than one route under the children
*                                it will becomes nested mode, otherwise not show the root menu
* redirect: noredirect           if `redirect:noredirect` will no redirct in the breadcrumb
* name:'router-name'             the name is used by <keep-alive> (must set!!!)
* meta : {
    roles: ['admin','editor']     will control the page roles (you can set multiple roles)
    title: 'title'               the name show in submenu and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar,
    noCache: true                if true ,the page will no be cached(default is false)
  }
**/

// 所有权限通用路由表
// 如首页和登录页和一些不用权限的公用页面

export const constantRouterMap = [
  { path: '/login', component: () => import('@/views/login/index'), hidden: true },
  { path: '/findPwd', component: () => import('@/views/findPwd/index'), hidden: true },
  { path: '/404', component: () => import('@/views/404'), hidden: true },
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    hidden: true,
    children: [{
      path: 'dashboard',
      component: () => import('@/views/dashboard'),
      name: 'dashboard',
      meta: { title: '主页' }
    }]
  }
]

// 实例化vue的时候只挂载constantRouter

export default new Router({
  // mode: 'history', //后端支持可开
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRouterMap
})

// 异步挂载的路由
// 动态需要根据权限加载的路由表

export const asyncRouterMap = [
  {
    path: '/show',
    component: common,
    redirect: '/show/home',
    meta: { roles: ['0', '1'] },
    hidden: true,
    children: [{
      path: 'home',
      component: () => import('@/views/home/index.vue'),
      name: 'home',
      meta: { title: '首页', roles: ['0', '1'] }
    },
    {
      path: 'medicalTreatment',
      component: () => import('@/views/medicalTreatment/index.vue'),
      name: 'medicalTreatment',
      meta: { title: '协同诊疗', roles: ['0', '1'] }
    },
    {
      path: 'intelligentJudgment',
      component: () => import('@/views/intelligentJudgment/index.vue'),
      name: 'intelligentJudgment',
      meta: { title: 'AI智能判断', roles: ['0', '1'] }
    },
    {
      path: 'sharedDevice',
      component: () => import('@/views/sharedDevice/index.vue'),
      name: 'sharedDevice',
      meta: { title: '共享器械', roles: ['0', '1'] }
    },
    {
      path: 'hospital',
      component: () => import('@/views/hospital/index.vue'),
      name: 'hospital',
      meta: { title: '医院', roles: ['0', '1'] }
    }]
  },
  {
    path: '',
    component: Layout,
    name: 'peoplesManage',
    meta: {
      title: '个人设置',
      icon: 'peoples',
      roles: ['0', '1']
    },
    alwaysShow: true,
    children: [
      {
        path: 'infoManage',
        name: 'infoManage',
        component: () => import('@/views/peoplesManage/infoManage/index'),
        meta: { title: '个人信息修改', roles: ['0', '1'] }
      },
      {
        path: 'accountSettings',
        name: 'accountSettings',
        component: () => import('@/views/peoplesManage/accountSettings/index'),
        meta: { title: '账户设置', roles: ['0', '1'] }
      }
    ]
  },
  {
    path: '',
    component: Layout,
    name: 'BridgesInfo',
    meta: {
      title: '',
      roles: ['1', '2']
    },
    alwaysShow: false,
    children: [
      {
        path: 'BridgesInfo',
        name: 'BridgesInfo',
        component: () => import('@/views/baseInfoManage/bridgesInfo/index'),
        meta: { title: '医院信息', icon: 'hospital' }
      }
    ]
  },
  {
    path: '',
    component: Layout,
    name: 'serversConfig',
    meta: {
      title: '',
      icon: 'list',
      roles: ['1', '2']
    },
    alwaysShow: false,
    children: [
      {
        path: 'serversConfig',
        name: 'serversConfig',
        component: () => import('@/views/baseInfoManage/serversConfig/index'),
        meta: { title: '科室信息', icon: 'Department' }
      }
    ]
  },
  {
    path: '',
    component: Layout,
    name: 'boxesConfig',
    meta: {
      title: '',
      icon: 'list',
      roles: ['1', '2']
    },
    alwaysShow: false,
    children: [
      {
        path: 'boxesConfig',
        name: 'boxesConfig',
        component: () => import('@/views/baseInfoManage/boxesConfig/index'),
        meta: { title: '医生信息', icon: 'doctor' }
      }
    ]
  },
  {
    path: '',
    component: Layout,
    name: 'sensorsConfig',
    meta: {
      title: '',
      icon: 'list',
      roles: ['1', '2']
    },
    alwaysShow: false,
    children: [
      {
        path: 'sensorsConfig',
        name: 'sensorsConfig',
        component: () => import('@/views/baseInfoManage/sensorsConfig/index'),
        meta: { title: '器械信息', icon: 'instrument' }
      }
    ]
  },
  { path: '*', redirect: '/404', hidden: true, meta: { roles: ['0', '1', '2'] }
  }
]
